@@ -95,7 +95,7 @@ class Dns:
             else:
                 services.remove(service)
 
-        data = {'update_token': domain.upddate_token, 'ip': external_ip, 'services': services}
+        data = {'update_token': domain.update_token, 'ip': external_ip, 'services': services}
 
         url = urljoin(self.api_url, "/domain/update")
 
