@@ -65,7 +65,7 @@ class Insider:
 
 def get_insider(bin_path, config_path, logs_path):
 
-    script_path = os.path.join(bin_path, 'insidercli')
+    script_path = os.path.join(bin_path, 'insider')
     insider_config_path = os.path.join(config_path, 'insider.cfg')
     cron_log_path = os.path.join(logs_path, 'insider-cron.log')
 
